; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10



;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1



;//////////////////////////AIR}h////////////////////////////////////



[Command]
name = "AI0"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI1"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI2"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI3"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI4"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI5"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI6"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI7"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI8"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI9"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI10"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI11"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI12"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI13"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI14"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI15"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI16"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI17"
command = a,B,c,x,y,z,s,B,D,F,U,a,b,c,x,y,z,s,s
time = 0
[Command]
name = "AI18"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI19"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI20"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI21"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI22"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI23"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI24"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI25"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI26"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI27"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI28"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI29"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI30"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI31"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI32"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI33"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI34"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI35"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI36"
command = z,z,z,z,z,z,a,a,a,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI37"
command = z,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,z,z,z
time = 0
[Command]
name = "AI38"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z
time = 0
[Command]
name = "AI39"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI40"
command = z,z,z,z,a,a,a,z,z,z,z,a,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI41"
command = z,z,z,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z,z
time = 0
[Command]
name = "AI42"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI43"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,a,a,z
time = 0
[Command]
name = "AI44"
command = z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,a,a,a,z
time = 0
[Command]
name = "AI45"
command = z,z,z,z,z,z,a,a,z,z,z,z,z,a,a,a,a,z,z
time = 0
[Command]
name = "AI46"
command = z,z,z,z,z,z,z,z,a,a,a,a,a,a,z,z,z,z,z
time = 0
[Command]
name = "AI47"
command = z,z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI48"
command = z,z,z,z,z,a,a,a,z,z,z,a,a,a,z,z,a,z,a
time = 0
[Command]
name = "AI49"
command = z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z,z
time = 0
[Command]
name = "AI50"
command = z,z,z,a,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z
time = 0@

[Command]
name = "AI51"
command = x, x
time = 0

[Command]
name = "AI51"
command = x, y
time = 0

[Command]
name = "AI52"
command = x, z
time = 0

[Command]
name = "AI53"
command = x, a
time = 0

[Command]
name = "AI54"
command = x, b
time = 0

[Command]
name = "AI55"
command = x, c
time = 0

[Command]
name = "AI56"
command = y, x
time = 0]

[Command]
name = "AI57"
command = y, y
time = 0

[Command]
name = "AI58"
command = y, z
time = 0

[Command]
name = "AI59"
command = y, a
time = 0

[Command]
name = "AI60"
command = y, b
time = 0

[Command]
name = "AI61"
command = z,z,z,a,z,z
time = 0
[Command]
name = "AI62"
command = z,z,z,F
time = 0
[Command]
name = "AI63"
command = b,x,D,F
time = 0
[Command]
name = "AI64"
command = s,z,a
time = 0
[Command]
name = "AI65"
command = U,D,a,x,y
time = 0
[Command]
name = "AI66"
command = B,a,a,a,a,U
time = 0
[Command]
name = "AI67"
command = x,y,z,s,a,b
time = 0
[Command]
name = "AI68"
command = s,DF,x,x,x
time = 0
[Command]
name = "AI69"
command = D,D,U,U,a,b
time = 0
[Command]
name = "AI70"
command = a,x,b,y,z,a,a,a,a
time = 0
[Command]
name = "AI71"
command = B,a,b,s,c,U,F,F,F,s
time = 0
[Command]
name = "AI72"
command = x,y,B,s,a,b,F,F,F,s
time = 0
[Command]
name = "AI73"
command = s,DF,x,x,x,U,U,F
time = 0
[Command]
name = "AI74"
command = D,D,U,U,a,b,F,F,F,D,B
time = 0
[Command]
name = "AI75"
command = a,x,b,y,z,a,a,a,a,F,F,F,s
time = 0
[Command]
name = "AI76"
command = U,U,F,F,F,F,B,U,D
time = 0
[Command]
name = "AI77"
command = s,s,s,s,s,B,F,D,a,s
time = 0
[Command]
name = "AI78"
command = b,D,b,U,s,a,c,x,a,F,x,F,s
time = 0
[Command]
name = "AI79"
command = B,U,F,U,U,F,B,U,D,z,z,z,b
time = 0
[Command]
name = "AI80"
command = z,x,a,a,c,U,F,D,a,U
time = 0



;-| TCo[EX |--------------------------------------------------------


;t@CiDED
[Command]
name = "Final DD"
command = ~D, DF, F,D, DF, F, x

[Command]
name = "Final DD"
command = ~D, DF, F,D, DF, F, y




;-| R}hZ |------------------------------------------------------




;hLm
[Command]
name = "QCF_x"
command = ~D, DF, F, x


;hLm(΋)
[Command]
name = "Dlill_tiku"
command = ~D, DF, F, y

;nCp[DEDiA1j
[Command]
name = "QCB_x"
command = ~F,B,F, x

;nCp[DEDiA2j
[Command]
name = "QCB_y"
command = ~F,B,F, y

;D3{
[Command]
name = "QCF_y"
command = ~D, DF, F, z

;D3{i߁j
[Command]
name = "Land Mine Ex near"
command = ~D, DB, B, z

;TCNX^v
[Command]
name = "QCF_z"
command=~D, DB, B, a
time=15

; _bVUiA1j
[Command]
name = "FFx"
command = F, F, x

;_bVUiA2j
[Command]
name = "FFy"
command = F, F, y

GXgsO
[Command]
name = "Oiuchi"
command = $D,y

GMKNbV
[Command]
name = "Giga Crush"
command = x+y

Gp[`[W
[Command]
name = "Recharge Power"
command = x+y


[Command]
name = "Special Reversal"
command = /B,c


;[Command]
;name = "Super Jump"
;command = D,$U

;----||---------------------------------------


;iA1j
[Command]
name = "Stand Throw"  ;while standing
command = /F,x

[Command]
name = "Stand Throw"  ;while standing
command = /B,x

;iA2j
[Command]
name = "Toss"
command = /F,y

[Command]
name = "Toss"
command = /B,y

[Command]
name = "Arm Twist"
command = ~B,F,z




;----|ʏ|---------------------------------------

[Command]
name = "A1+A2"     ;Required (do not remove)
command = x+y
time = 10

;-| u[Xg |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1


;-| {^ |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| z[h |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdx"
command = /x
time = 1


[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holds"
command = /s
time = 1



;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]


;---------------------------------------------------------------------------





;---------------------------------------------------------------------------

[State -1,t@CiDED]
type = ChangeState
value = 3000
triggerall = Var(59) = 0
triggerall = command = "Final DD"
triggerall = power >= 1000
triggerall = statetype != A
triggerall = var(57) != 4
trigger1 = ctrl
trigger2 = var(51)
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger6 = stateno = 140 || stateno = 141 ||  stateno = 150 || stateno = 151 
trigger7 = stateno = 100 || stateno = 105



;---------------------------------------------------------------------------
[State -1, MKNbV]
type = ChangeState
value = 1230
triggerall = Var(59) = 0
triggerall = command = "Giga Crush"
triggerall = power >= 1000
triggerall = StateType != A
trigger1 = ctrl 
trigger2 = var(51) = 1
trigger3 = stateno = 100 || stateno = 105

;---------------------------------------------------------------------------
[State -1, hLm]
type = ChangeState
value = 1240
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "QCF_x"
triggerall = StateType != A
triggerall = NumHelper(2300) <= 0
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno = stateno =2300 && time >= 21|| stateno =2301 && time >= 20
trigger6 = stateno = 100 || stateno = 105 

;---------------------------------------------------------------------------
[State -1, hLm(΋)]
type = ChangeState
value = 1270
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "Dlill_tiku"
triggerall = StateType != A
triggerall = NumHelper(2300) <= 0
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno = stateno =2300 && time >= 21|| stateno =2301 && time >= 20
trigger6 = stateno = 100 || stateno = 105 

;---------------------------------------------------------------------------
[State -1, nCp[DEDiA1j]
type = ChangeState
value = 1250
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "QCB_x"
triggerall = StateType != A
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger6 = stateno = 100 || stateno = 105


[State -1, nCp[DEDiA2j]
type = ChangeState
value = 1255
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "QCB_y"
triggerall = StateType != A
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno = stateno =2300 && time >= 21|| stateno =2301 && time >= 20
trigger6 = stateno = 100 || stateno = 105 

;---------------------------------------------------------------------------
[State -1, D3{]
type = ChangeState
value = 1260
triggerall = Var(59) = 0
triggerall = command = "QCF_y"
triggerall = StateType != A
triggerall = fvar(23) = 0
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger6 = stateno = 100 || stateno = 105

;---------------------------------------------------------------------------
[State -1, D3{i߁j]
type = ChangeState
value = 1261
triggerall = Var(59) = 0
triggerall = command = "Land Mine Ex near"
triggerall = StateType != A
triggerall = fvar(23) <= 0
trigger1 = ctrl
trigger2 = var(51) = 1
trigger3 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger4 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger5 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger6 = stateno = 100 || stateno = 105

;---------------------------------------------------------------------------

[State -1, n]
type = ChangeState
value = 2300
triggerall = Var(59) = 0
triggerall = statetype = S
triggerall = fvar(23) <= 0
triggerall = command = "z"
trigger1 = ctrl
trigger2 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger3 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger4 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20
trigger5 = stateno = 100 || stateno = 105


[State -1, ni߁j]
type = ChangeState
value = 2301
triggerall = Var(59) = 0
triggerall = statetype = C
triggerall = command = "z"
triggerall = fvar(23) <= 0
trigger1 = ctrl
trigger2 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger3 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger4 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger5 = stateno = 100 || stateno = 105


[State -1, ni󒆁j]
type = ChangeState
value = 2302
triggerall = Var(59) = 0
triggerall = command <= "z"
triggerall = fvar(23) = 0
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger3 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13|| stateno = 630 && time >= 9
trigger4 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 
trigger5 = stateno = 100


;===========================================================================
[State -1, ʏR{P]
type = ChangeState
value = 1000
triggerall = Var(59) = 0
triggerall = var(57) != 4
trigger1 = command = "x"
trigger1 = Stateno = 200
trigger1 = MoveContact
;trigger1 = Time >= 10

;------------------------------------------------------------------------------
[State -1, ʏR{Q]
type = ChangeState
value = 1001
triggerall = Var(59) = 0
triggerall = var(57) != 4
trigger1 = command = "y"
trigger1 = Stateno = 1000
trigger1 = MoveContact
trigger1 = Time >= 8
trigger2 = command = "y"
trigger2 = Stateno = 200
trigger2 = MoveContact
trigger2 = Time >= 8


;---------------------------------------------------------------------------
;---------------------------------------------------------------------------


[State -1,Release b]
type = VarSet
trigger1 = command = "holdb"
triggerall = Var(59) = 0
triggerall = Stateno = 100 ||  Stateno = 105 || Stateno = 50 || Stateno = 54
var(55) = 0

[State -1,Release b]
type = VarSet
trigger1 = command != "holdb"
triggerall = Var(59) = 0
triggerall = Stateno != 100 ||  Stateno != 105 || Stateno != 50 || Stateno != 54
var(55) = 55

;u[Xg
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = Var(59) = 0
triggerall = var(55) = 55
triggerall = Stateno != [100,151]
triggerall = statetype = S
triggerall = command != "holddown"
triggerall = command != "holdup"
triggerall = ctrl
trigger1 = command = "FF"
trigger2 = command != "holdback"
trigger2 = command = "holdb"

;---------------------------------------------------------------------------
;obNu[Xg
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = Var(59) = 0
triggerall = var(55) = 55
triggerall = Stateno != 105
triggerall = statetype = S
triggerall = command != "holddown"
triggerall = command != "holdup"
triggerall = ctrl||(Stateno = 151 && time >= 8)
trigger1 = command = "BB"
trigger2 = command = "holdback"
trigger2 = command = "holdb"
trigger3 = command = "BB"|| command = "holdback" && command = "holdb"


;---------------------------------------------------------------------------

[State -1, 󒆃u[Xg]
type = ChangeState
value = 54
triggerall = var(54) < 3
triggerall = Stateno = 54
triggerall = statetype = A
triggerall = ctrl
triggerall = Var(59) = 0
trigger1 = command = "b"

[State -1]
type = varadd
trigger1 = stateno = 54
trigger1 = Time = 1
var(54) = 1



;---------------------------------------------------------------------------

[State -1,iA1j]
type = ChangeState
value = 800
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = p2statetype != A
triggerall = p2stateno!=[150,155]
triggerall = p2statetype != L
triggerall = command = "Stand Throw"
triggerall = p2BodyDist X <=7
triggerall = ctrl
triggerall = stateno != 100
triggerall = P2BodyDist Y <= 0
Triggerall = Var(17) = 0
trigger1 = statetype = S
;---------------------------------------------------------------------------

[State -1, iA2j]
type = ChangeState
value = 830
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = (p2statetype != A)||(enemynear,gethitvar(fall)=1&&p2bodydist y >=-40)
triggerall = p2stateno!=[150,155]
triggerall = command = "Toss"
triggerall = p2BodyDist X <=7
triggerall = ctrl
triggerall = P2BodyDist Y <= 0
Triggerall = Var(17) = 0
trigger1 = stateno != 100
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, Arm Twist]
type = null;ChangeState
value = 860
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "start"
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = S



;===========================================================================
;---------------------------------------------------------------------------

[State -1, A1]
type = ChangeState
value = 200
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "x"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, rȂ]
type = ChangeState
value = 207
triggerall = Var(59) = 0
triggerall = var(57) = 4
triggerall = command = "x"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, A2]
type = ChangeState
value = 210
triggerall = Var(59) = 0
triggerall = var(57) != 4
triggerall = command = "y"
;triggerall = command != "holdfwd"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S


;---------------------------------------------------------------------------
[State -1,  _bVA1]
type = ChangeState
value = 300
triggerall = Var(59) = 0
triggerall = ctrl
triggerall = statetype = S
trigger1 = command = "FFx"
trigger2 = command = "x"
trigger2 = stateno = 100

;---------------------------------------------------------------------------
[State -1, _bVA2]
type = ChangeState
value = 310
triggerall = Var(59) = 0
triggerall = ctrl
triggerall = statetype = S
trigger1 = command = "FFy"
trigger2 = command = "y"
trigger2 = stateno = 100
;---------------------------------------------------------------------------
[State -1, ]
type = null;ChangeState
value = 195
triggerall = Var(59) = 0
triggerall = command = "start"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

[State -1, ႪA1]
type = ChangeState
value = 400
triggerall = Var(59) = 0
triggerall = command = "x"
triggerall = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
[State -1, ႪA2]
type = ChangeState
value = 430
triggerall = Var(59) = 0
triggerall = command = "y"
triggerall = ctrl
trigger1 = statetype = C


;---------------------------------------------------------------------------
[State -1, A1+A2]
type = ChangeState
value = 645
triggerall = Var(59) = 0
triggerall = command = "A1+A2"
triggerall = command != "holddown"
triggerall = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, A1]
type = ChangeState
value = 630
triggerall = Var(59) = 0
triggerall = command = "x"
triggerall = ctrl
trigger1 = statetype = A


;---------------------------------------------------------------------------
[State -1, A2]
type = ChangeState
value = 640
triggerall = Var(59) = 0
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = ctrl
trigger1 = statetype = A



;---------------------------------------------------------------------------
[State -1, XgsO]
type = ChangeState
value = 650
triggerall = Var(59) = 0
triggerall = command = "Oiuchi"
triggerall = ctrl
trigger1 = statetype = A


;---------------------------------------------------------------------------
[State -1,TCNX^v]
type = ChangeState
value = 670
triggerall = Var(59) = 0
triggerall = ctrl
triggerall = command = "QCF_z"
trigger1 = statetype != A

;---------------------------------------------------------------------------
[State -1, Nオ]
type = ChangeState
value = 701
triggerall = Var(59) = 0
triggerall = stateno = 5120
trigger1 = command = "b"
trigger1 = Time = 1


;---------------------------------------------------------------------------
[State -1, p[`[W]
type = ChangeState
value = 1220
triggerall = Var(59) = 0
triggerall = command = "holdy"
triggerall = command = "holdx"
triggerall = power < 1000
trigger1 = ctrl 
trigger1 = stateno != 1220
trigger1 = StateType = S
trigger2 = stateno = 200 && time >= 8 || stateno = 210 && time >= 7 || stateno = 300 && time >= 8
trigger3 = stateno = 310 && time >= 10|| stateno = 400 && time >= 13
trigger4 = stateno =2300 && time >= 21|| stateno =2301 && time >= 20 


;============================================================================================================================================================
; wp[p
;==============================================================================
;-------------------------------------------------------------------------
;PlayerID擾ׂ̃wp[
;------------------------------------------------------------------------------
[Statedef 886600]
anim = 195
ctrl = 0
[STATE PlayerIDSet]
type=ParentVarSet
trigger1=Parent,ID=Helper(887700),ID
var(34)=ID
[state ]
type=DestroySelf
trigger1=1
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
[Statedef 887700]
type     = S
movetype = I
physics  = N
ctrl     = 0
velset   = 0,0
anim     = 195
sprpriority = -1
;------------------------------------------------------------------------------
[STATE AIJn]
type = VarSet
trigger1 = 1
var(2) = 0
persistent=0
[STATE AIJn]
type = VarAdd
trigger1 = RoundState=2
var(2) = 1
[STATE AIJn]
type = ChangeState
trigger1 = var(2)>40
value = 887701;40t[Α̏펞Ďwp[͋NĂ
;------------------------------------------------------------------------------
[Statedef 887701]
;------------------------------------------------------------------------------
; 
[STATE BtR]
type = BindToRoot
trigger1 = 1
time = 100000
pos = 0,0
[STATE Turn];߂΍ROOTƋtA{̂̌둤InGuardDist擾
type = Turn
trigger1 = facing=root,facing;BtRfacing͓IȌ͕ςȂ炵
[STATE \]
type = AssertSpecial
trigger1 = 1
flag = invisible
flag2= noshadow
[STATE G]
type = NOTHITBY
trigger1 = 1
value = SCA
time = 999999
[STATE 0]
type = VarSet
trigger1 = 1
var(2) = 0

;------------------------------------------------------------------------------
; AI - KE
;------------------------------------------------------------------------------
[STATE KE]
type = VarSet
triggerall = Time
trigger1 = var(0)>enemy,power
var(1) = floor((var(0)-enemy,power)*0.001)
[STATE KE(Zbg)]
type = VarSet
triggerall = Time
trigger1 = enemynear,movetype=H
trigger2 = enemynear,stateno=[0,105]
trigger3 = enemynear,stateno=[120,155]
trigger4 = enemynear,stateno=[5000,5210]
var(1) = 0
[STATE ENEMY,POWER]
type = VarSet
trigger1 = Time
var(0) = enemynear,power
;------------------------------------------------------------------------------
; AI - wp[Ď
;------------------------------------------------------------------------------
[STATE DEBUG]
type = DisplayToClipboard
trigger1 = Time
text = "HELPER:%d %d %d %d %d "
params = var(11),var(12),var(13),var(14),var(15)
[STATE DEBUG]
Type = AppendToClipBoard
trigger1 = Time
text = "%d %d %d %d %d"
params = var(16),var(17),var(18),var(19),var(30)
[STATE DEBUG]
Type = AppendToClipBoard
trigger1 = Time
text = "\n50:%d 51:%d 52:%d 53:%d 54:%d"
params = var(50),var(51),var(52),var(53),var(54)
[STATE PlayerID擾tO]
type = VarSet
triggerall = Time
trigger1 = Enemy,NumHelper>var(3)	;̃wp[
var(4) = 1
[STATE ]
type = VarSet
trigger1 = Time
var(3) = Enemy,NumHelper
[STATE PlayerIDAdd]
type = Helper
triggerall = Time
trigger1 = RoundState=2
trigger1 = var(4)
name = " "
id = 886600
stateno = 886600
supermovetime = 99990000000
pausemovetime = 99990000000
[STATE wp[]
type = VarSet
triggerall = Time
trigger1 = NumHelper(886600)
trigger1 = var(4)
var(7) = helper(886600),ID-var(34)+2
;------------------------------------------------------------------------------
[STATE xtÕZbg]
type = VarRangeSet
trigger1 = Time
first = 50
last = 54
value = 0
;------------------------------------------------------------------------------
[STATE PlayerID擾]
type = ChangeState
triggerall = Time
trigger1 = RoundState=2
trigger1 = var(5):=11+0||1
trigger1 = var(4):=0||1
value = 887711
;==============================================================================
; wp[Ď[v
[Statedef 887711]
[STATE Zbg1];݂ȂPlayerIDi[ĂVAR̓Zbg
type = VarSet
trigger1 = PlayerIDExist(var(var(5)))=0
var(var(5)) = 0
[STATE Zbg2];Upwp[ł͂ȂƎvwp[PlayerID̓Zbg
type = VarSet
triggerall = PlayerIDExist(var(var(5)))
trigger1 = EnemyNear,MoveContact=[1,2]
trigger1 = PlayerID(var(var(5))),Time<=2
trigger2 = PlayerID(var(var(5))),MoveType!=A&&PlayerID(var(var(45))),time>120
trigger3 = PlayerID(var(var(5))),time>600
trigger4 = PlayerID(var(var(5))),command="holdfwd"
trigger5 = PlayerID(var(var(5))),Time=0
var(var(5)) = 0
[STATE }[LOZbg]
type = VarSet
trigger1 = PlayerIDExist(var(var(5)))=0
var(var(5)+10) = 0
;------------------------------------------------
; ѓĎ 
[STATE ѓĎ(HitDef^)]
type = NULL
triggerall = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(var(5))),MoveType=A;U
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP;Ũwp[
trigger1 = PlayerID(var(var(5))),Vel X>0;OiĂ
trigger1 = PlayerID(var(var(5))),Pos Y<10;nʂɂ߂荞łȂ
trigger1 = var(50):=(var(50)|255-Ceil(PlayerID(var(var(5))),P2BodyDist X))||1
trigger1 = var(50):=(var(50)|512*abs(Ceil(PlayerID(var(var(5))),Pos Y/2)))||1
trigger1 = var(50):=(var(50)|131072*Ceil(PlayerID(var(var(5))),Vel X))	||1
trigger1 = var(50):=(var(50)|4194304*(15-Ceil(PlayerID(var(var(5))),Vel Y)))
[STATE ѓĎ(Proj^)]
type = NULL
triggerall = PlayerIDExist(var(var(5)))
triggerall = var(var(5))=var(var(5)+10)	;}[LOwp[
trigger1 = EnemyNear,NumProj;肪ProjectileoĂ
trigger1 = PlayerID(var(var(5))),MoveType=I
trigger1 = !(PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP)
trigger1 = PlayerID(var(var(5))),Vel X>0
trigger1 = PlayerID(var(var(5))),Pos Y<10
trigger1 = var(50):=(var(50)|255-Ceil(PlayerID(var(var(5))),P2BodyDist X))||1
trigger1 = var(50):=(var(50)|512*abs(Ceil(PlayerID(var(var(5))),Pos Y/2)))||1
trigger1 = var(50):=(var(50)|131072*Ceil(PlayerID(var(var(5))),Vel X))||1
trigger1 = var(50):=(var(50)|4194304*(15-Ceil(PlayerID(var(var(5))),Vel Y)))
; ѓĎ 2
[STATE ѓĎ(HitDef^)]
type = NULL
triggerall = PlayerIDExist(var(var(5)))
trigger1 = var(50);߂łɂ鎞
trigger1 = PlayerID(var(var(5))),MoveType=A;U
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP;Ũwp[
trigger1 = PlayerID(var(var(5))),Vel X>0;OiĂ
trigger1 = PlayerID(var(var(5))),Pos Y<10;nʂɂ߂荞łȂ
trigger1 = var(51):=(var(51)|255-Ceil(PlayerID(var(var(5))),P2BodyDist X))||1
trigger1 = var(51):=(var(51)|512*abs(Ceil(PlayerID(var(var(5))),Pos Y/2)))||1
trigger1 = var(51):=(var(51)|131072*Ceil(PlayerID(var(var(5))),Vel X))||1
trigger1 = var(51):=(var(51)|4194304*(15-Ceil(PlayerID(var(var(5))),Vel Y)))
[STATE ѓĎ(Proj^)]
type = NULL
triggerall = PlayerIDExist(var(var(5)))
triggerall = var(var(5))=var(var(5)+10);}[LOwp[
trigger1 = EnemyNear,NumProj;肪ProjectileoĂ
trigger1 = var(50)
trigger1 = PlayerID(var(var(5))),MoveType=I
trigger1 = !(PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP)
trigger1 = PlayerID(var(var(5))),Vel X>0
trigger1 = PlayerID(var(var(5))),Pos Y<10
trigger1 = var(51):=(var(51)|255-Ceil(PlayerID(var(var(5))),P2BodyDist X))||1
trigger1 = var(51):=(var(51)|512*abs(Ceil(PlayerID(var(var(5))),Pos Y/2)))||1
trigger1 = var(51):=(var(51)|131072*Ceil(PlayerID(var(var(5))),Vel X))||1
trigger1 = var(51):=(var(51)|4194304*(15-Ceil(PlayerID(var(var(5))),Vel Y)))
;------------------------------------------------
;Ď
[STATE 򓹋(HitDef^)]
type = VarSet
triggerall = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(var(5))),MoveType=A
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP
trigger1 = PlayerID(var(var(5))),Vel X = [-1,1]
trigger1 = PlayerID(var(var(5))),Vel Y >= 1
trigger1 = PlayerID(var(var(5))),P2BodyDist X=[-100,100]
trigger1 = PlayerID(var(var(5))),P2Dist Y>0
var(52) = 1+Ceil(PlayerID(var(var(5))),P2BodyDist Y-PlayerID(var(var(5))),Vel Y*10)
;̑O100px͈͓ɗѓۂ̂ƁAVar(51)ɗѓ̍܂
[STATE 򓹋(Proj^)]
type = VarSet
triggerall = PlayerIDExist(var(var(5)));ォ痈ѓ(P)
triggerall = var(var(5))=var(var(5)+10)
trigger1 = PlayerID(var(var(5))),MoveType=I
trigger1 = !(PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP)
trigger1 = PlayerID(var(var(5))),Vel X = [-1,1]
trigger1 = EnemyNear,NumProj
trigger1 = PlayerID(var(var(5))),Vel Y >= 1
trigger1 = PlayerID(var(var(5))),P2BodyDist X=[-100,100]
trigger1 = PlayerID(var(var(5))),P2Dist Y>0
var(52) = 1+Ceil(PlayerID(var(var(5))),P2BodyDist Y-PlayerID(var(var(5))),Vel Y*10)
;ݒux
[STATE ݒu(ߋ)]
type = VarSet
triggerall = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(var(5))),MoveType=A
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP
trigger1 = PlayerID(var(var(5))),Vel Y = 0
trigger1 = PlayerID(var(var(5))),Vel X = 0
trigger1 = PlayerID(var(var(5))),P2BodyDist X=[-100,100]
trigger1 = PlayerID(var(var(5))),P2BodyDist Y=[-100,100]
var(53) = IfElse(PlayerID(var(var(5))),P2Dist X>0,1,-1)
;100px͈͓ɐݒuwp[ۂ̂1Aɂ-1
[STATE ݒu(אڋ)]
type = VarSet
triggerall = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(var(5))),MoveType=A
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP
trigger1 = PlayerID(var(var(5))),Vel Y = 0
trigger1 = PlayerID(var(var(5))),Vel X = 0
trigger1 = PlayerID(var(var(5))),P2BodyDist X=[-35,35]
trigger1 = PlayerID(var(var(5))),P2BodyDist Y=[-60,60]
var(53) = IfElse(PlayerID(var(var(5))),P2Dist X>0,10,-10)
;Xɋ߂ꍇ10Aɂ-10
[STATE ݒu()]
type = VarSet
triggerall = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(var(5))),MoveType=A
trigger1 = PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP
trigger1 = PlayerID(var(var(5))),Vel Y = 0
trigger1 = PlayerID(var(var(5))),Vel X = 0
trigger1 = PlayerID(var(var(5))),P2BodyDist X!=[-100,100]
trigger1 = PlayerID(var(var(5))),P2BodyDist X=[-350,350]
trigger1 = PlayerID(var(var(5))),P2BodyDist Y=[-100,100]
var(54) = IfElse(PlayerID(var(var(5))),P2Dist X>0,1,-1)
;Ɍ1Aɂ-1
;//////////////////////////////////////////////////////////////////////////////
[STATE loop]
type = ChangeState
trigger1 = var(5)<=11+10
trigger1 = var(5):=var(5)+1
value = StateNo
[STATE end]
type = ChangeState
trigger1 = var(5)>11+10
trigger1 = var(5):=11||1
value = 887712
;==============================================================================
; VAR
[Statedef 887712]
[STATE VARl߂]
type = NULL
triggerall = !var(var(5))
trigger1 = var(var(5)):=var(ifelse(var(5)+1>20,2,var(5)+1))||1
;Var(2)0ŌŒ肳Ă̂ŁA0
trigger1 = (var(var(5)):=var(ifelse(var(5)+1>20,2,var(5)+1)))||(var(ifelse(var(5)+1>20,2,var(5)+1)):=0)||1
[STATE loop]
type = ChangeState
trigger1 = var(5)<=11+10
trigger1 = var(5):=var(5)+1
value = StateNo
[STATE end]
type = ChangeState
trigger1 = var(5)>11+10
trigger1 = var(5):=0||1
value = IfElse(var(7)>0,887710,887701)
;------------------------------------------------------------------------------
;==============================================================================
; PlayerID擾
[Statedef 887710]
[STATE PlayerID擾]
type = VarSet
trigger1 = var(7)>10
var(7) = 10
[STATE PlayerIDi[VAR]
type = VarSet
trigger1 = 1
var(5) = 11+(var(11)>0)+(var(12)>0)+(var(13)>0)+(var(14)>0)+(var(15)>0)+(var(16)>0)+(var(17)>0)+(var(18)>0)+(var(19)>0)+(var(20)>0)
[STATE PlayerID擾]
type = VarSet
trigger1 = PlayerIDExist(var(34)-var(7));PlayerID݂
trigger1 = (var(34)-var(7))!=var(var(5)-1);do^̖h~
trigger1 = PlayerID(var(34)-var(7)),IsHelper;wp[Ɍ
trigger1 = PlayerID(var(34)-var(7)),IsHomeTeam!=IsHomeTeam;葤Ɍ
var(var(5)) = PlayerID(var(34)-var(7)),ID
[STATE }[LO];ѓKEZƎvXe[gŌĂяoꂽwp[}[LO
type = VarSet
trigger1 = PlayerIDExist(var(var(5)))
trigger1 = PlayerID(var(34)-var(7)),IsHelper
trigger1 = PlayerID(var(var(5))),MoveType!=A||!(PlayerID(var(var(5))),HitDefAttr=SCA,AA,AP,AT);U薳
trigger1 = EnemyNear,MoveType=A	;肪U̎ɌĂяoꂽ
trigger1 = !(EnemyNear,HitDefAttr=SCA,AA,AP,AT);肪HitDefoĂȂ(ѓ?)
trigger1 = EnemyNear,CTRL=0
trigger1 = EnemyNear,Time>10
trigger1 = EnemyNear,StateNo>=1000;1000ȏȂKEZ
var(var(5)+10) = PlayerID(var(var(5))),ID
[STATE loop]
type = ChangeState
trigger1 = var(7)>0
trigger1 = var(7):=var(7)-1||1
value = 887701
[STATE end]
type = ChangeState
trigger1 = var(7)<=0
value = 887701
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
[Statedef 997702]
anim = 195
ctrl = 0

[State -2]
type=Nothitby
trigger1=1
value=SCA

[State -2];seB
type=assertspecial
trigger1=1
flag=noshadow
flag2=invisible
ignorehitpause=1

[State -2]
type=BindToRoot
trigger1=1
facing=1
pos=90,0

[State -3];Nオ薳GԌv(Ō)
Type = VarSet
Trigger1 = P2StateType = L
V = 56
Value = -1
IgnoreHitPause = 1

[State -3]
Type = VarAdd
TriggerAll = Var(56) > 0
Trigger1 = P2StateType != L
V = 56
Value = -1
IgnoreHitPause = 1

[State -3]
Type = VarSet
TriggerAll = Var(56) = -1
Trigger1 = P2StateType != L
V = 56
Value = 3
IgnoreHitPause = 1

[State -3];Nオ薳GԌv()
Type = VarSet
Trigger1 = P2StateType = L
V = 49
Value = -1
IgnoreHitPause = 1

[State -3]
Type = VarAdd
TriggerAll = Var(49) > 0
Trigger1 = P2StateType != L
V = 49
Value = -1
IgnoreHitPause = 1

[State -3]
Type = VarSet
TriggerAll = Var(49) = -1
Trigger1 = P2StateType != L
V = 49
Value = 12
IgnoreHitPause = 1

[STATE -3,F];܂
type = Varset
trigger1 = parent,var(39) = 2
trigger1 = enemynear,movetype=A
trigger1 = !enemynear,hitdefattr=SCA,AA,AT
trigger1 = (parent,var(39)&63)<63
var(3) = 1
IgnoreHitPause = 1
[STATE -3,F];܂off
type = VarSet
triggerall = var(3) = 1
trigger1 = enemynear,movetype=A
trigger1 = enemynear,hitdefattr=SCA,AA,AT
trigger1 = var(4):=var(3);
trigger2 = enemynear,movetype != A
var(3) = 0
IgnoreHitPause = 1
[STATE -3];off
type = VarSet
triggerall = var(4) = 1
trigger1 = enemynear,movetype != A
var(4) = 0
IgnoreHitPause = 1

[STATE -3];K[h
type = Varset
trigger1 = var(4)=1
trigger1 = parent,stateno=[150,153]
trigger1 = enemynear,movetype=A&&enemynear,ctrl=0
var(5) = 1
IgnoreHitPause = 1
[STATE -3];K[hoff
type = VarSet
triggerall = var(5) = 1
trigger1 = parent,stateno!=[120,155]
var(5) = 0
IgnoreHitPause = 1

[STATE -3];_bVA2HIT
type = Varset
trigger1 = parent,stateno=310
trigger1 = parent,movehit=1&&enemynear,ctrl=0&&(enemynear,stateno=[5000,5040])&&p2movetype=H
var(6) = 1
IgnoreHitPause = 1
[STATE -3];_bVA2HIToff
type = VarSet
triggerall = var(6) = 1
trigger1 = p2movetype!=H
trigger2 = p2statetype=L
var(6) = 0
IgnoreHitPause = 1

[State -1];d|
type = VarRandom
triggerall = parent,statetype != A
triggerall = var(7) = 0
trigger1 = p2statetype != A
trigger1 = parent,ctrl&&p2movetype = H&&enemynear,gethitvar(guarded)=1
trigger1 = enemynear,gethitvar(hittime) >= 6
trigger1 = parent,p2bodydist x<=120
trigger1 = parent,p2dist x >= 0
V = 7
range = 1,4
IgnoreHitPause = 1

[State -1];nd|
type = Varset
triggerall = parent,statetype != A
triggerall = var(8) = 1
triggerall = var(7) = 0
trigger1 = parent,p2bodydist x <= 62
trigger1 = parent,p2dist x >= 0
trigger1 = parent,stateno=20040
V = 7
value = 3
IgnoreHitPause = 1

[State -3];d|off
Type = VarSet
triggerall = var(7)>=1
trigger1 = p2movetype = A
trigger2 = parent,movetype = H
trigger3 = parent,movetype = A
trigger4 = p2statetype = A
trigger5 = p2statetype = L
V = 7
Value = 0
IgnoreHitPause = 1

[State -1];nd|
type = VarRandom
triggerall = parent,statetype != A
triggerall = var(8) = 0
trigger1 = parent,var(40)=10
trigger1 = parent,p2dist x >= 0
V = 8
range = 1,6
IgnoreHitPause = 1

[State -3];nd|off
Type = VarSet
triggerall = var(8)>=1
trigger1 = p2movetype = A && (enemynear,hitdefattr=SCA,HA,ST,HT)
trigger2 = parent,statetype = L
trigger3 = parent,movetype = A && (parent,stateno!=[2300,2302])
trigger4 = p2statetype = A && enemynear,vel y <= -40
trigger5 = p2statetype = L
trigger6 = p2dist x < 0
trigger7 = p2movetype = H
V = 8
Value = 0
IgnoreHitPause = 1

[State -1];A1Rrl[V
type = Varset
triggerall = parent,statetype != A
triggerall = var(9) = 0
trigger1 = parent,stateno=1000&&parent,movehit&&p2movetype=H&&p2statetype!=A
trigger1 = p2stateno=[5000,5040]
V = 9
value = 1
IgnoreHitPause = 1

[State -3];A1Rrl[Voff
Type = VarSet
triggerall = var(9)=1
trigger1 = p2movetype != H || enemynear,ctrl = 1 || enemynear,life=0
V = 9
Value = 0
IgnoreHitPause = 1

[State -1];ɂ
type = Varset
triggerall = var(10) = 0
trigger1 = random <= 300
trigger1 = parent,power<1000
trigger1 = (parent,stateno=[2300,2302])&&parent,time=14&&parent,p2bodydist x>57&&!(p2statetype=A&&enemynear,pos y<-35)
V = 10
value = 1
IgnoreHitPause = 1

[State -3];ɂoff
Type = VarSet
triggerall = var(10)=1
trigger1 = p2movetype = H || enemynear,life=0
trigger2 = parent,movetype = A && (parent,time= [1,2])
trigger3 = parent,inguarddist
trigger4 = parent,movetype = H
trigger5 = parent,stateno=[20040,20042]
trigger6 = p2statetype=A&&enemynear,pos y<-35
trigger7 = p2stateno =[150,155]
V = 10
Value = 0
IgnoreHitPause = 1
--------------------------------------------------------------------
[Statedef 997703]
anim = 195
ctrl = 0

[State -2]
type=Nothitby
trigger1=1
value=SCA

[State -2];seB
type=assertspecial
trigger1=1
flag=noshadow
flag2=invisible
ignorehitpause=1

[State -2]
type=BindToRoot
trigger1=1
facing=1
pos=-100,0

--------------------------------------------------------------------
